CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_sample_run.c File Reference

CCL

Data Structures | Macros | Functions
ccl_sample_run.c File Reference
`#include <stdlib.h>`
`#include <stdio.h>`
`#include <math.h>`
`#include "ccl.h"`
`#include "ccl_lsst_specs.h"`

## Data Structures
struct | user_func_params

## Macros
#define | OC 0.25
#define | OB 0.05
#define | OK 0.00
#define | ON 0.00
#define | HH 0.70
#define | W0 -1.0
#define | WA 0.00
#define | NS 0.96
#define | NORMPS 0.80
#define | ZD 0.5
#define | NZ 128
#define | Z0_GC 0.50
#define | SZ_GC 0.05
#define | Z0_SH 0.65
#define | SZ_SH 0.05
#define | NL 512
#define | PS 0.1
#define | NREL 3.046
#define | NMAS 0
#define | MNU 0.0

## Functions
double | user_pz_probability (double z_ph, double z_s, void *user_par, int *status)
int | main (int argc, char **argv)

## Macro Definition Documentation

## ◆ HH

#define HH 0.70

## ◆ MNU

#define MNU 0.0

## ◆ NL

#define NL 512

## ◆ NMAS

#define NMAS 0

## ◆ NORMPS

#define NORMPS 0.80

## ◆ NREL

#define NREL 3.046

## ◆ NS

#define NS 0.96

## ◆ NZ

#define NZ 128

## ◆ OB

#define OB 0.05

## ◆ OC

#define OC 0.25

## ◆ OK

#define OK 0.00

## ◆ ON

#define ON 0.00

## ◆ PS

#define PS 0.1

## ◆ SZ_GC

#define SZ_GC 0.05

## ◆ SZ_SH

#define SZ_SH 0.05

## ◆ W0

#define W0 -1.0

## ◆ WA

#define WA 0.00

## ◆ Z0_GC

#define Z0_GC 0.50

## ◆ Z0_SH

#define Z0_SH 0.65

## ◆ ZD

#define ZD 0.5

## Function Documentation

## ◆ main()

int main | ( | int | argc,
|  | char ** | argv
| ) |  |

## ◆ user_pz_probability()

double user_pz_probability | ( | double | z_ph,
|  | double | z_s,
|  | void * | user_par,
|  | int * | status
| ) |  |